@@ -89,6 +89,7 @@ static t_cached_object *remove_from_cache(t_cached_object *object, int index) {
 
 static bool add_object_to_cache(t_cached_object *object) {	
 	int index;
+	t_cached_object *search;
 
 	if (object == NULL) {
 		return false;
@@ -102,6 +103,15 @@ static bool add_object_to_cache(t_cached_object *object) {
 	object->next = cache[index];
 	if (cache[index] != NULL) {
 		cache[index]->prev = object;
+
+		search = cache[index];
+		while (search != NULL) {
+			if (strcmp(search->file, object->file) == 0) {
+				search->deadline = 0;
+				break;
+			}
+			search = search->next;
+		}
 	}
 	cache[index] = object;
 
@@ -253,20 +263,22 @@ static char *make_url(t_session *session, char *request_uri) {
 t_cached_object *add_cgi_output_to_cache(t_session *session, char *cgi_output, int size, int time) {
 	t_cached_object *object;
 	size_t len;
-	char *pos, *data, str[50];
+	char *pos, *loc, *data, str[50];
 
 	if ((pos = strstr(cgi_output, "\r\n\r\n")) == NULL) {
 		return NULL;
 	}
 	*pos = '\0';
-	if (strcasestr(cgi_output, hs_conlen) == NULL) {
+	loc = strcasestr(cgi_output, hs_conlen);
+	*pos = '\r';
+
+	if (loc == NULL) {
 		/* Output has no Content-Length
 		 */
 		len = size - (pos + 4 - cgi_output);
 		sprintf(str, "%s%ld\r\n", hs_conlen, len);
 		len = strlen(str);
 		if ((data = (char*)malloc(len + size)) == NULL) {
-			*pos = '\r';
 			return NULL;
 		}
 		memcpy(data, str, len);
@@ -276,12 +288,10 @@ t_cached_object *add_cgi_output_to_cache(t_session *session, char *cgi_output, i
 		/* Output has Content-Length
 		 */
 		if ((data = (char*)malloc(size)) == NULL) {
-			*pos = '\r';
 			return NULL;
 		}
 		memcpy(data, cgi_output, size);
 	}
-	*pos = '\r';
 
 	if ((object = (t_cached_object*)malloc(sizeof(t_cached_object))) == NULL) {
 		free(data);
@@ -400,8 +410,6 @@ void check_cache(time_t now) {
 				if (object->in_use <= 0) {
 					object = remove_from_cache(object, index);
 					continue;
-				} else {
-					object->deadline = 0;
 				}
 			}
 			object = object->next;
@@ -467,7 +475,7 @@ void print_cache_list(FILE *fp) {
 		object = cache[i];
 		while (object != NULL) {
 			fprintf(fp, "  Filename  : %s\n", object->file);
-			fprintf(fp, "  File size : %lld bytes\n", (long long)object->size);
+			fprintf(fp, "  File size : %.2f kB\n", (float)(object->size) / KILOBYTE);
 			if ((secs = object->deadline - now) > 0) {
 				fprintf(fp, "  Time left : %d seconds\n\n", secs);
 			} else {
@@ -481,7 +489,7 @@ void print_cache_list(FILE *fp) {
 		pthread_mutex_unlock(&cache_mutex[i]);
 	}
 
-	fprintf(fp, "  Total: %lld bytes in %d cache objects.\n", (long long)size, files);
+	fprintf(fp, "  Total: %.2f MB in %d cache objects.\n", (float)(size) / MEGABYTE, files);
 }
 
 off_t size_of_cache(void) {
