@@ -17,8 +17,10 @@
 #include "global.h"
 #include "libip.h"
 
-#define TIME_IN_CACHE     MINUTE
-#define MAX_CACHE_TIMER     HOUR
+#define TIME_IN_CACHE      MINUTE
+#define MAX_CACHE_TIMER      HOUR
+#define MIN_CGI_CACHE_TIMER     2
+#define MAX_CGI_CACHE_TIMER  HOUR
 
 typedef struct type_cached_object {
 	char          *file;
@@ -28,14 +30,18 @@ typedef struct type_cached_object {
 	time_t        last_changed;
 	volatile int  in_use;
 	t_ip_addr     last_ip;
+	enum {cot_file, cot_cgi} type;
 
 	struct type_cached_object *prev;
 	struct type_cached_object *next;
 } t_cached_object;
 
 void init_cache_module(void);
-t_cached_object *add_to_cache(t_session *session, char *file);
-t_cached_object *search_cache(t_session *session, char *file);
+t_cached_object *add_file_to_cache(t_session *session, char *file);
+t_cached_object *search_cache_for_file(t_session *session, char *file);
+t_cached_object *add_cgi_output_to_cache(t_session *session, char *cgi_output, int size, int time);
+t_cached_object *search_cache_for_cgi_output(t_session *session);
+void remove_cgi_output_from_cache(t_session *session, char *url);
 void done_with_cached_object(t_cached_object *object, bool remove_object);
 void check_cache(time_t time);
 int clear_cache(void);
