@@ -9,8 +9,8 @@
  * GNU General Public License for more details.
  */
 
-#ifndef _LIBCGI_H
-#define _LIBCGI_H
+#ifndef _CGI_H
+#define _CGI_H
 
 #include <stdbool.h>
 #include <time.h>
