@@ -43,10 +43,12 @@ t_headerfield *parse_headerfields(char *line) {
 		return NULL;
 	}
 	headerfield->data = line;
+	headerfield->length = 0;
 	headerfield->next = NULL;
 	while (*line != '\0') {
 		if (*line == '\r') {
 			*line = '\0';
+			headerfield->length = strlen(headerfield->data);
 			if (*(line + 1) == '\n') {
 				if ((*(line + 2) != '\r') && (*(line + 2) != '\0')) {
 					if ((headerfield->next = (t_headerfield*)malloc(sizeof(t_headerfield))) == NULL) {
@@ -55,14 +57,26 @@ t_headerfield *parse_headerfields(char *line) {
 					headerfield = headerfield->next;
 					headerfield->next = NULL;
 					headerfield->data = line + 2;
+					headerfield->length = 0;
 				} else {
 					break;
 				}
+			} else {
+				headerfield->data = line + 1;
 			}
 		}
 		line++;
 	}
 
+	if (first->length == 0) {
+		free(first);
+		return NULL;
+	}
+
+	if (headerfield->length == 0) {
+		headerfield->length = strlen(headerfield->data);
+	}
+
 	headerfield = first;
 	while (headerfield != NULL) {
 		if ((value = strchr(headerfield->data, ':')) != NULL) {
