@@ -566,6 +566,7 @@ int init_sqli_detection(void) {
 int prevent_sqli(t_session *session, char *str, int length) {
 	char *data;
 	t_sqli_pattern *pattern;
+	int result = 0;
 
 	if ((str == NULL) || (length <= 0)) {
 		return 0;
@@ -586,13 +587,14 @@ int prevent_sqli(t_session *session, char *str, int length) {
 			monitor_counter_exploit_attempt(session);
 #endif
 
-			return 1;
+			result = 1;
+			break;
 		}
 
 		pattern = pattern->next;
 	}
 
-	return 0;
+	return result;
 }
 
 /* Prevent Cross-site Request Forgery
